# geoedemo


[![image](https://img.shields.io/pypi/v/geoedemo.svg)](https://pypi.python.org/pypi/geoedemo)
[![image](https://binder.pangeo.io/badge_logo.svg)](https://binder.pangeo.io/v2/gh/shakurgds/geemap/master)
[![image](https://img.shields.io/pypi/v/geemap.svg)](https://pypi.python.org/pypi/geoedemo)
[![image](https://pepy.tech/badge/geemap)](https://pepy.tech/project/geoedemo)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/giswqs/geemap.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/shakurgds/geoedemo/context:python)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


**Python package musings for geo**


-   Free software: MIT license
-   Documentation: https://shakurgds.github.io/geoedemo
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
